pub struct SyntaxHighlighter { /* private fields */ }Implementations
Sourceimpl SyntaxHighlighter
impl SyntaxHighlighter
pub fn new() -> Self
pub fn set_theme(&mut self, theme_name: &str)
pub fn available_themes(&self) -> Vec<String>
pub fn detect_language( &self, text: &str, file_extension: Option<&str>, ) -> Option<String>
Sourcepub fn clear_state_from_line(&mut self, line_number: usize, language: &str)
pub fn clear_state_from_line(&mut self, line_number: usize, language: &str)
Clear cached highlighting state from a specific line onward. This is useful for incremental re-highlighting when text changes.
Sourcepub fn reset_state(&mut self)
pub fn reset_state(&mut self)
Reset all cached highlighting state. Call this when the buffer content has significantly changed.
pub fn highlight_line( &mut self, line: &str, language: &str, line_number: usize, font_family: SharedString, _font_size: f32, ) -> Vec<TextRun>
Sourcepub fn ensure_parse_states(
&mut self,
language: &str,
up_to_line: usize,
lines: &[String],
)
pub fn ensure_parse_states( &mut self, language: &str, up_to_line: usize, lines: &[String], )
Ensure parse states exist up to a given line by parsing from the beginning if needed
pub fn get_theme_background(&self) -> Hsla
pub fn get_theme_foreground(&self) -> Hsla
pub fn get_theme_gutter_background(&self) -> Hsla
pub fn get_theme_line_highlight(&self) -> Hsla
pub fn get_theme_selection(&self) -> Hsla
pub fn load_theme_from_file(&mut self, path: &str) -> Result<(), String>
pub fn load_syntax_from_file(&mut self, path: &str) -> Result<(), String>